Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
TEST, BENCH, IFDEF) (#345, @NathanReb)strict_with so it applies to extensible variant types in the same way it applies to variant types (#350, @NathanReb)- would be rejected as ocp-indent input argument instead of being interpreted as stdin (#351, @NathanReb)let type, let external, let class (#354, @NathanReb)--strict flag to make warnings fatal and parsing stricter (#356, @NathanReb)--check flag and corresponding check mode which does not print indented version but instead succeed if the input is already correctly indented and fails otherwise. (#357, @NathanReb)?filename argument to Nstream functions to allow properly setting the filename for parsing errors. (#357, @NathanReb)|> as a monadic operator (#322, @nberth)ocp-indent-gen-rules to support dune fmt like workflow with ocp-indent (#333, @NathanReb)[@...]) to better match the actual meaning.~/.config)(*$)IndentBlock.is_at_top now returns true for top-level expressionslet f = fun x -> and let f =\n fun x ->